gchecky.test.gxml'.XmlFieldTestCase

Package gchecky :: Package test :: Module gxml' :: Class XmlFieldTestCase |
[hide private]
[frames] | no frames]

# Class XmlFieldTestCase

source code

           object --+
                    |
    unittest.TestCase --+
                        |
                       XmlFieldTestCase

Nested Classes | [hide private]
Inherited from `unittest.TestCase`: `failureException`

Instance Methods | [hide private]
ensure_result_equals_source(self, result, source) | source code
testAnyFieldXml(self) | source code
testDeconstructPath(self) Test Field.deconstruct_path method | source code
testZipFieldXml(self) | source code
Inherited from `unittest.TestCase`: `__call__`, `__init__`, `__repr__`, `__str__`, `assertAlmostEqual`, `assertAlmostEquals`, `assertEqual`, `assertEquals`, `assertFalse`, `assertNotAlmostEqual`, `assertNotAlmostEquals`, `assertNotEqual`, `assertNotEquals`, `assertRaises`, `assertTrue`, `assert_`, `countTestCases`, `debug`, `defaultTestResult`, `fail`, `failIf`, `failIfAlmostEqual`, `failIfEqual`, `failUnless`, `failUnlessAlmostEqual`, `failUnlessEqual`, `failUnlessRaises`, `id`, `run`, `setUp`, `shortDescription`, `tearDown` Inherited from `unittest.TestCase` (private): `_exc_info` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Class Variables | [hide private]
| gxml

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

### gxml Value: gchecky.test.gxml'